def json_load_file(json_file, encoding="utf-8"):
    r"""Get content of a json file

    Args:
        path (str): path to the file

    Returns:
        dictionary (dict)

    """
    with open(json_file, encoding=encoding) as read_file:
        return json.load(read_file, cls=TrailingCommaJSONDecoder)


class TrailingCommaJSONDecoder(json.JSONDecoder):
    def decode(self, s, *args, **kwargs):
        # Remove trailing commas before decoding
        s = self._remove_trailing_commas(s)
        return super().decode(s, *args, **kwargs)

    def _remove_trailing_commas(self, s):
        # A simple implementation to remove trailing commas
        # This might not handle all edge cases, but it works for most common cases
        return s.replace(",}", "}").replace(",]", "]")


def json_load_file_with_comments(file_path):
    """
    Load a JSON file with comments removed.

    Args:
        file_path (str): Path to the JSON file.

    Returns:
        dict: JSON data without comments.
    """
    contents = ""
    with open(file_path) as fh:
        for line in fh:
            cleaned_line = line.split("//", 1)[0]
            if len(cleaned_line) > 0 and line.endswith("\n") and "\n" not in cleaned_line:
                cleaned_line += "\n"
            contents += cleaned_line
    while "/*" in contents:
        pre_comment, post_comment = contents.split("/*", 1)
        contents = pre_comment + post_comment.split("*/", 1)[1]

    cleaned_json = json.loads(contents)
    return cleaned_json


def json_load_dirty(dirty_json):
    """
    Load a dirty JSON string.

    Args:
        dirty_json (str): Dirty JSON string.

    Returns:
        dict: Cleaned JSON data.
    """
    regex_replace = [
        (r"(?<!\\)\"(?!\\)", r'"'),  # Replace single quotes with double quotes
        (r"(\b[tf])", lambda m: m.group(1).lower()),  # Replace True/False with true/false
    ]
    for r, s in regex_replace:
        dirty_json = re.sub(r, s, dirty_json)
    clean_json = json.loads(dirty_json)
    return clean_json


def json_load_dirty_file(file_path):
    """
    Load a dirty JSON file.

    Args:
        file_path (str): Path to the dirty JSON file.

    Returns:
        dict: Cleaned JSON data.
    """
    with open(file_path, "rb") as file:
        data = file.read()
    encoding = chardet.detect(data)["encoding"]
    if encoding:
        data = data.decode(encoding)
    return json_load_dirty(data)
